"""
    This file is part of pytripgui.

    pytripgui is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    pytripgui is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with pytripgui.  If not, see <http://www.gnu.org/licenses/>
"""
import os
import sys


def get_class_name(item):
    return item.__class__.__name__


def get_resource_path(res):
    return os.path.join(os.path.join(get_main_dir(), "res"), res)


def get_main_dir():
    if getattr(sys, 'frozen', False):
        return os.environ.get("_MEIPASS2", os.path.abspath("."))
        # when using single directory installer, this one should be probably used:
        # return os.path.dirname(sys.executable)
    else:
        return os.path.dirname(__file__)


def get_default_plugin_path():
    path = os.path.join(get_user_directory(), "plugins")
    if not os.path.exists(path):
        os.makedirs(path)
    return path


def get_base_plugin_path():
    return os.path.join(get_main_dir(), "baseplugins")


def get_user_directory():
    path = os.path.join(os.path.expanduser("~"), ".pytrip")
    if not os.path.exists(path):
        os.makedirs(path)
    return path


def find_path(path, active_folder=None):
    path = os.path.expandvars(path)
    if os.path.exists(path):
        return path
    elif active_folder is not None and os.path.exists(os.path.join(active_folder, path)):
        return os.path.join(active_folder, path)
    return None


def get_args_from_string(string):
    temp = string[string.find("(") + 1:string.find(")")]
    return temp.split(",")


def get_func_from_string(string):
    idx = string.find("(")
    if idx > -1:
        return string[0:idx]
    return None


def is_ms_windows():
    """Are we running on Windows?

    @rtype: Bool"""
    from wx import Platform
    return Platform == '__WXMSW__'


def is_mac():
    """Are we running on Mac

    @rtype: Bool"""
    from wx import Platform
    return Platform == '__WXMAC__'
